Struct gltf::material::PbrMetallicRoughness [−][src]
pub struct PbrMetallicRoughness<'a> { /* fields omitted */ }Expand description
A set of parameter values that are used to define the metallic-roughness material model from Physically-Based Rendering (PBR) methodology.
Implementations
Returns the material’s base color factor.
The default value is [1.0, 1.0, 1.0, 1.0].
Returns the base color texture. The texture contains RGB(A) components in sRGB color space.
Returns the metalness factor of the material.
The default value is 1.0.
Returns the roughness factor of the material.
- A value of 1.0 means the material is completely rough.
- A value of 0.0 means the material is completely smooth.
The default value is 1.0.
The metallic-roughness texture.
The metalness values are sampled from the B channel. The roughness values are sampled from the G channel. These values are linear. If other channels are present (R or A), they are ignored for metallic-roughness calculations.